@@ -1,23 +1,31 @@
 #ifndef BONNIE
 #define BONNIE
 
-#define BON_VERSION "1.03"
+using namespace std;
+
+#define BON_VERSION "1.96"
+#define CSV_VERSION "1.96"
 
-#include "conf.h"
 #include "port.h"
+#include <stdio.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+
+typedef FILE *PFILE;
 
 #define SemKey 4711
 #define NumSems TestCount
-// million files (7) + up to 12 random extra chars
+// 9 billion files (10) + up to 12 random extra chars
 #define RandExtraLen (12)
-#define MaxNameLen (7 + RandExtraLen)
+#define MaxNameLen (10 + RandExtraLen)
 // data includes index to which directory (6 bytes) and terminating '\0' for
 // the name and pointer to file name
-#define MaxDataPerFile (MaxNameLen + 6 + 1 + 4)
+#define MaxDataPerFile (MaxNameLen + 6 + 1 + sizeof(void *))
 #define MinTime (0.5)
 #define Seeks (8192)
 #define UpdateSeek (10)
-#define SeekProcCount (3)
+#define SeekProcCount (5)
 #define DefaultChunkBits (13)
 #define DefaultChunkSize (1 << DefaultChunkBits)
 #define UnitBits (20)
@@ -28,25 +36,14 @@
 #define DefaultDirectorySize 16
 #define DefaultDirectoryMaxSize 0
 #define DefaultDirectoryMinSize 0
-// 1024M per file for IO.
-#define IOFileSize 1024
-// 3 digits
-#define MaxIOFiles 1000
-
-typedef const char * PCCHAR;
-typedef char * PCHAR;
-typedef PCHAR const CPCHAR;
-typedef PCCHAR const CPCCHAR;
-typedef void * PVOID;
-typedef PVOID const CPVOID;
-typedef const CPVOID CPCVOID;
+#define DefaultByteIO 3
 
 enum tests_t
 {
-  Putc = 0,
+  ByteWrite = 0,
   FastWrite,
   ReWrite,
-  Getc,
+  ByteRead,
   FastRead,
   Lseek,
   CreateSeq,
@@ -58,7 +55,15 @@ enum tests_t
   TestCount
 };
 
-int   io_error(CPCCHAR message, bool do_exit = false);
+int io_error(CPCCHAR message, bool do_exit = false);
 int bon_setugid(CPCCHAR user, CPCCHAR group, bool quiet);
+unsigned int size_from_str(CPCCHAR str, CPCCHAR conv);
+
+typedef enum
+{
+  eNoErr = 0,
+  eParam = 1,
+  eCtrl_C = 5
+} ERROR_TYPE;
 
 #endif
